@@ -32,19 +32,14 @@
 #include <unistd.h>
 #include <fcntl.h>
 
-#include <bluetooth/bluetooth.h>
-#include <bluetooth/hci.h>
-#include <bluetooth/rfcomm.h>
-
 #include <glib.h>
 
 #include <openobex/obex.h>
-#include <openobex/obex_const.h>
 
-#include "obexd.h"
 #include "logging.h"
 #include "bluetooth.h"
 #include "obex.h"
+#include "obex-priv.h"
 #include "dbus.h"
 #include "btio.h"
 #include "service.h"
@@ -54,13 +49,13 @@
 
 static GSList *servers = NULL;
 
-static void confirm_event(GIOChannel *io, gpointer user_data)
+static void confirm_event(GIOChannel *io, void *user_data)
 {
 	struct server *server = user_data;
 	struct obex_service_driver *driver;
 	GError *err = NULL;
 	char address[18];
-	guint8 channel;
+	uint8_t channel;
 
 	bt_io_get(io, BT_IO_RFCOMM, &err,
 			BT_IO_OPT_DEST, address,
@@ -95,24 +90,23 @@ drop:
 	g_io_channel_shutdown(io, TRUE, NULL);
 }
 
-static gint server_start(struct server *server)
+static int server_start(struct server *server)
 {
 	GError *err = NULL;
 	struct obex_service_driver *driver;
+	BtIOSecLevel sec_level;
 
 	driver = (struct obex_service_driver *) server->drivers->data;
 
-	/* Listen */
 	if (server->secure)
-		server->io = bt_io_listen(BT_IO_RFCOMM, NULL, confirm_event,
-					server, NULL, &err,
-					BT_IO_OPT_CHANNEL, driver->channel,
-					BT_IO_OPT_SEC_LEVEL, BT_IO_SEC_MEDIUM,
-					BT_IO_OPT_INVALID);
+		sec_level = BT_IO_SEC_MEDIUM;
 	else
-		server->io = bt_io_listen(BT_IO_RFCOMM, NULL, confirm_event,
+		sec_level = BT_IO_SEC_LOW;
+
+	server->io = bt_io_listen(BT_IO_RFCOMM, NULL, confirm_event,
 					server, NULL, &err,
 					BT_IO_OPT_CHANNEL, driver->channel,
+					BT_IO_OPT_SEC_LEVEL, sec_level,
 					BT_IO_OPT_INVALID);
 	if (!server->io)
 		goto failed;
@@ -126,7 +120,7 @@ failed:
 	return -EINVAL;
 }
 
-static gint server_stop(struct server *server)
+static int server_stop(struct server *server)
 {
 	if (!server->io)
 		return -EINVAL;
@@ -143,9 +137,9 @@ static gint server_stop(struct server *server)
 	return 0;
 }
 
-static gint server_register(guint16 service, const gchar *folder,
+static int server_register(uint16_t service, const char *folder,
 				gboolean secure, gboolean auto_accept,
-				gboolean symlinks, const gchar *capability)
+				gboolean symlinks, const char *capability)
 {
 	struct server *server;
 	GSList *drivers;
@@ -169,12 +163,12 @@ static gint server_register(guint16 service, const gchar *folder,
 	return 0;
 }
 
-gint bluetooth_init(guint service, const gchar *folder, gboolean secure,
+int bluetooth_init(unsigned int service, const char *folder, gboolean secure,
 				gboolean auto_accept, gboolean symlinks,
-				const gchar *capability)
+				const char *capability)
 {
 	return server_register(service, folder, secure, auto_accept, symlinks,
-					capability);
+								capability);
 }
 
 void bluetooth_exit(void)
@@ -192,7 +186,7 @@ void bluetooth_start(void)
 		if (server_start(server) < 0)
 			continue;
 
-		register_record(server, NULL);
+		register_record(server);
 	}
 }
 
